function prepare_data_biogrid_yeast_ppi_cyc2008_complexes()
  % Prepare a dataset of physical protein-protein interactions in yeast from the biogrid database
  % with CYC2008 complexes
  more off;
  
  complex_file = 'ppi/CYC2008_complex.tab';
  ppi_file = 'ppi/BIOGRID-ORGANISM-Saccharomyces_cerevisiae_S288c-3.4.131.tab2.txt';
  
  % Read ppi
  fprintf('Loading PPI\n');
  ppi_temp = tmpnam();
  system(sprintf('cut -f6,7,13,14 %s > %s',ppi_file,ppi_temp));
  [p1,p2,p3,p4] = textread(ppi_temp,'%s %s %s %s','delimiter','\t');
  assert(isequal(p1{1},'Systematic Name Interactor A')); p1 = p1(2:end);
  assert(isequal(p2{1},'Systematic Name Interactor B')); p2 = p2(2:end);
  assert(isequal(p3{1},'Experimental System Type')); p3 = p3(2:end);
  assert(isequal(p4{1},'Author')); p4 = p4(2:end);
  unlink(ppi_temp);
  
  % Read complexes
  fprintf('Loading Complexes\n');
  complex_temp = tmpnam();
  system(sprintf('cut -f1,2,3 %s > %s',complex_file,complex_temp));
  [c1,c2,c3] = textread(complex_temp,'%s %s %s','delimiter','\t');
  assert(isequal(c1{1},'ORF')); c1 = c1(2:end); % c1 = systematic name / uniprot id
  assert(isequal(c2{1},'Name')); c2 = c2(2:end); % c2 = name
  assert(isequal(c3{1},'Complex')); c3 = c3(2:end); % c3 = complex
  unlink(complex_temp);
  
  % Subsets to consider
  subsets = {};
  subsets{end+1} = struct('suffix','', 'physical',1);
  subsets{end+1} = struct('suffix','-all');
  subsets{end+1} = struct('suffix','-gavin-2006', 'author','Gavin AC (2006)');
  subsets{end+1} = struct('suffix','-collins-2007', 'author','Collins SR (2007)');
  subsets{end+1} = struct('suffix','-costanzo-2010', 'author','Costanzo M (2010)');
  subsets{end+1} = struct('suffix','-hoppins-2011', 'author','Hoppins S (2011)');
  subsets{end+1} = struct('suffix','-krogan-2006', 'author','Krogan NJ (2006)');
  for is = 1:numel(subsets)
    subset = subsets{is};
    filename = sprintf('ppi-yeast-cyc2008%s.mat', subset.suffix);
    fprintf('Mapping to integers and saving: %s\n', filename);
  
    % Convert to a matrix
    [protein_names,unused,p12] = unique([p1,p2]);
    pi1 = p12(1:length(p1));
    pi2 = p12(length(p1)+1:end);
    if isfield(subset,'author')
      % keep only experiments by author
      keep = cellfun(@(x)isequal(x,subset.author),p4);
    elseif isfield(subset,'physical')
      % keep only physical experiments
      keep = cellfun(@(x)isequal(x,'physical'),p3);
    else
      keep = 1:length(p1);
    end
    pi1 = pi1(keep);
    pi2 = pi2(keep);
    
    A = sparse(pi1,pi2,1,length(protein_names),length(protein_names));
    A = A | A';
    A = double(A);
    A = A - diag(diag(A)); % remove self loops
    
    % map complexes unto these ids
    assert(all(ismember(c1,protein_names)));
    ci = lookup(protein_names, c1, 'm');
    % ids for complexes
    [complex_names,unused,complexid] = unique(c3);
    C = sparse(ci,complexid,1,length(protein_names),length(complex_names));
    assert(size(C,2) == 408); % CYC2008 has 408 complexes
    
    fprintf('Nodes: %d, Edges: %d, Complexes: %d\n', size(C,1), nnz(A), size(C,2));
    
    % save
    save('-v7',filename,'protein_names','complex_names','A','C');
  end
end

